==> netgen-6.2.2307_0+python311+x11.darwin_10.ppc.tbz2: opt/local/lib/cmake/netgen/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2307")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2307")
set(NETGEN_VERSION_TWEAK "v6.2.2307")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;JPEGLIB;FFMPEG;__STDC_CONSTANT_MACROS")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../../../include" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../../" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../python3.11/site-packages" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_math_netgen/netgen/work/netgen-6.2.2307")

set(NETGEN_BUILD_FOR_CONDA "OFF")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "")
set(NETGEN_FFMPEG_LIBRARIES "/opt/local/lib/libavcodec.dylib;/opt/local/lib/libavformat.dylib;/opt/local/lib/libavutil.dylib;/opt/local/lib/libswscale.dylib")
set(NETGEN_JPEG_INCLUDE_DIR "/opt/local/include")
set(NETGEN_JPEG_LIBRARIES "/opt/local/lib/libjpeg.dylib")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "")
set(NETGEN_METIS_LIBRARY "")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "")
set(NETGEN_OCC_LIBRARIES_BIN "")
set(NETGEN_OCC_LIBRARIES "")
set(NETGEN_OCC_LIBRARY_DIR "")
set(NETGEN_OPENGL_LIBRARIES "/opt/local/lib/libGL.dylib")
set(NETGEN_PYTHON_EXECUTABLE "/opt/local/bin/python3.11")
set(NETGEN_PYTHON_INCLUDE_DIRS "/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include/python3.11")
set(NETGEN_PYTHON_LIBRARIES "/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/libpython3.11.dylib")
set(NETGEN_TCL_INCLUDE_PATH "/opt/local/include")
set(NETGEN_TCL_LIBRARY "/opt/local/lib/libtclstub8.6.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/opt/local/include")
set(NETGEN_TK_LIBRARY "/opt/local/lib/libtkstub8.6.a")
set(NETGEN_X11_X11_LIB "/opt/local/lib/libX11.dylib")
set(NETGEN_X11_Xmu_LIB "/opt/local/lib/libXmu.dylib")
set(NETGEN_ZLIB_INCLUDE_DIRS "/opt/local/include")
set(NETGEN_ZLIB_LIBRARIES "/opt/local/lib/libz.dylib")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI OFF)
set(NETGEN_USE_OCC OFF)
set(NETGEN_USE_JPEG ON)
set(NETGEN_USE_MPEG ON)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE OFF)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "../../")
set(NETGEN_RPATH_TOKEN "$ORIGIN")

set(NETGEN_INSTALL_DIR_PYTHON lib/python3.11/site-packages)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB lib)
set(NETGEN_INSTALL_DIR_INCLUDE include)
set(NETGEN_INSTALL_DIR_CMAKE lib/cmake/netgen)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")

==> netgen-6.2.2307_1+python311+x11.darwin_10.ppc.tbz2: opt/local/lib/cmake/netgen/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2307")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2307")
set(NETGEN_VERSION_TWEAK "v6.2.2307")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;JPEGLIB;FFMPEG;__STDC_CONSTANT_MACROS")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../../../include" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../../" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../python3.11/site-packages" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/opt/local/var/macports/build/_opt_local_ppcports_math_netgen/netgen/work/netgen-6.2.2307")

set(NETGEN_BUILD_FOR_CONDA "OFF")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "")
set(NETGEN_FFMPEG_LIBRARIES "/opt/local/lib/libavcodec.dylib;/opt/local/lib/libavformat.dylib;/opt/local/lib/libavutil.dylib;/opt/local/lib/libswscale.dylib")
set(NETGEN_JPEG_INCLUDE_DIR "/opt/local/include")
set(NETGEN_JPEG_LIBRARIES "/opt/local/lib/libjpeg.dylib")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "")
set(NETGEN_METIS_LIBRARY "")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "")
set(NETGEN_OCC_LIBRARIES_BIN "")
set(NETGEN_OCC_LIBRARIES "")
set(NETGEN_OCC_LIBRARY_DIR "")
set(NETGEN_OPENGL_LIBRARIES "/opt/local/lib/libGL.dylib")
set(NETGEN_PYTHON_EXECUTABLE "/opt/local/bin/python3.11")
set(NETGEN_PYTHON_INCLUDE_DIRS "/opt/local/Library/Frameworks/Python.framework/Versions/3.11/include/python3.11")
set(NETGEN_PYTHON_LIBRARIES "/opt/local/Library/Frameworks/Python.framework/Versions/3.11/lib/libpython3.11.dylib")
set(NETGEN_TCL_INCLUDE_PATH "/opt/local/include")
set(NETGEN_TCL_LIBRARY "/opt/local/lib/libtclstub8.6.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/opt/local/include/tk-x11")
set(NETGEN_TK_LIBRARY "/opt/local/lib/tk-x11/libtkstub8.6.a")
set(NETGEN_X11_X11_LIB "/opt/local/lib/libX11.dylib")
set(NETGEN_X11_Xmu_LIB "/opt/local/lib/libXmu.dylib")
set(NETGEN_ZLIB_INCLUDE_DIRS "/opt/local/include")
set(NETGEN_ZLIB_LIBRARIES "/opt/local/lib/libz.dylib")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI OFF)
set(NETGEN_USE_OCC OFF)
set(NETGEN_USE_JPEG ON)
set(NETGEN_USE_MPEG ON)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE OFF)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "../../")
set(NETGEN_RPATH_TOKEN "$ORIGIN")

set(NETGEN_INSTALL_DIR_PYTHON lib/python3.11/site-packages)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB lib)
set(NETGEN_INSTALL_DIR_INCLUDE include)
set(NETGEN_INSTALL_DIR_CMAKE lib/cmake/netgen)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")
